% Aggregate Stability and Balanced-Budget Rules
% Matteo F. Ghilardi and Raffaele Rossi
%
% This code reproduces figure one in the paper
% The indeterminate area can be seen on the x axis in white.

clc
clear all



%% Parameters

delta=0.1;
theta=0.3;
vp=0;
ACD=1;
AlphaCD=0.3;
Frisch=0;
pi=0.04;


startin=1.8;
endin=0.2;
Sigma=(startin:-0.2:endin);
Ctax=0;
LTax=(0.0025:0.0025:0.9975);

aaaa=size(LTax);
sise2=aaaa(2);
cccc=size(Sigma);
sise3=cccc(2);

numbers=numel(Sigma);
col=numbers/3;

ncol=1;


for counter2=1:1:sise3;
    sigma=Sigma(counter2);
    

    for counter1=1:1:sise2
        Ltax=LTax(counter1);
        
if sigma==1
    sigma=1.00001;
end

%% Steady State Cobb Douglas
r=((1-Ctax)*delta+pi)/(1-Ctax); % interest rate

GammaCD=(r*(1/AlphaCD))^(1/(1-AlphaCD));

PiCD=((1-AlphaCD)*GammaCD^(1-AlphaCD)*Ltax)+(AlphaCD*GammaCD^(1-AlphaCD)-delta)*Ctax;

KCD=(((1-AlphaCD)*GammaCD^(-AlphaCD)*(1-Ltax))/(ACD*GammaCD^Frisch*(GammaCD^(1-AlphaCD)-PiCD-delta)))^(1/(1+Frisch)); % S.S. Capital
HCD=GammaCD*KCD;  % S.S. Labour
KCD_HCD=KCD/HCD; % Capital-Labour Ratio
KCD_HCD1=1/GammaCD; % Capital-Labour Ratio 2 (just a proof, it must have the same value of the one above)
CCD=(GammaCD^(1-AlphaCD)-PiCD-delta)*KCD; % S.S. Consumption
G=PiCD*KCD;  % S.S. Government
Psi=(sigma-1)/sigma;   
w=(1-AlphaCD)*GammaCD^(-AlphaCD);   % S.S. Wages

YCD=KCD^AlphaCD*HCD^(1-AlphaCD);   % S.S Output




        
%% Parameters CES

AlphaGUO=(AlphaCD)/(AlphaCD+(1-AlphaCD)*(KCD_HCD)^Psi);

CESGUO=(AlphaGUO*(KCD)^Psi+(1-AlphaGUO)*(HCD)^Psi)^(1/Psi);
BGUO=YCD/CESGUO;

AGUO=((1-AlphaGUO)*BGUO^Psi*YCD^(-Psi)*(1-delta*KCD/YCD)^(-1))/HCD^(1+Frisch-Psi);

%% Steady State CES

YCES=BGUO*(AlphaGUO*KCD^(Psi)+(1-AlphaGUO)*HCD^(Psi))^(1/Psi);



%% Model

AA=[(Frisch)    (Ltax/(1-Ltax))    -1    0    0;...
    -((Ltax*w*HCD)/G)    -((Ltax*w*HCD+Ctax*(r-delta)*KCD)/G)    -((Ltax*w*HCD)/G)    0    -((Ctax*r*KCD)/G);...
    0    0    0    (-(1/sigma))    1;...
    (1/sigma)    0    1    (-(1/sigma))    0;...
    (-(1-AlphaGUO))*(BGUO*(HCD/YCD))^(Psi)    0    0    1    0];

BB=[0    -1;...
    ((Ctax*(r-delta)*KCD/G))    0;...
    (-(1/sigma))    0;...
    0    0;...
    (AlphaGUO*(BGUO*(KCD/YCD))^(Psi))   0];


XX=(AA)^(-1)*BB;


CC=[-delta    -(CCD/KCD);...
    0    (((r-delta)*(1-Ctax))-pi)];
    

DD=[0    0    0    (YCD/KCD)    0;...
    0    -Ctax*(r-delta)    0    0    r*(1-Ctax)];



matrix=(DD*(inv(AA)*BB))+CC;
     
deter=det(matrix); 
tr=trace(matrix);


figure(1)
hold all
if deter<0; subplot(col,3,ncol), plot (Ltax, Ctax, '.k','markersize',1);
elseif tr>0 subplot(col,3,ncol), plot (Ltax, Ctax, '.r','markersize',1);
else subplot(col,3,ncol), plot (Ltax, Ctax, '.w','markersize',1);
%title('\sigma=startin')
        xlabel('Labour-Income Tax');
        ylabel('Tax Revenue');
              
end

  

figure(1)
hold all
plot (Ltax, G, '.k','markersize',5);
   

end
ncol=ncol+1;
startin=startin+0.1;
end