% Aggregate Stability and Balanced-Budget Rules
% Matteo F. Ghilardi and Raffaele Rossi
%
% This code reproduces figure two in the paper



clc;
clear all;


%% Parameters

delta=0.1;
theta=0.3;
vp=0;
ACD=1;
AlphaCD=0.3;
Frisch=0;
pi=0.04;


startin=1.8;
endin=0.2;
Sigma=(startin:-0.2:endin);
CTax=(0.005:0.005:0.995);
LTax=(0.005:0.005:0.995);

aaaa=size(LTax);
sise2=aaaa(2);
bbbb=size(CTax);
sise1=bbbb(2);
cccc=size(Sigma);
sise3=aaaa(2);

numbers=numel(Sigma);
col=numbers/3;

ncol=1;

%% US Block

    
for counter=1:1:sise1;
    Ctax=CTax(counter);
    for counter1=1:1:sise2
        Ltax=LTax(counter1);
sigma=1.8;        
if sigma==1
    sigma=1.00001;
end

%% Steady State Cobb Douglas
r=((1-Ctax)*delta+pi)/(1-Ctax); % interest rate
GammaCD=(r*(1/AlphaCD))^(1/(1-AlphaCD));
PiCD=((1-AlphaCD)*GammaCD^(1-AlphaCD)*Ltax)+(AlphaCD*GammaCD^(1-AlphaCD)-delta)*Ctax;
KCD=(((1-AlphaCD)*GammaCD^(-AlphaCD)*(1-Ltax))/(ACD*GammaCD^Frisch*(GammaCD^(1-AlphaCD)-PiCD-delta)))^(1/(1+Frisch)); % S.S. Capital
HCD=GammaCD*KCD;  % S.S. Labour
KCD_HCD=KCD/HCD; % Capital-Labour Ratio
CCD=(GammaCD^(1-AlphaCD)-PiCD-delta)*KCD; % S.S. Consumption
G=PiCD*KCD;  % S.S. Government
Psi=(sigma-1)/sigma;   
w=(1-AlphaCD)*GammaCD^(-AlphaCD);   % S.S. Wages
YCD=KCD^AlphaCD*HCD^(1-AlphaCD);   % S.S Output




        
%% Parameters CES

AlphaGUO=(AlphaCD)/(AlphaCD+(1-AlphaCD)*(KCD_HCD)^Psi);

CESGUO=(AlphaGUO*(KCD)^Psi+(1-AlphaGUO)*(HCD)^Psi)^(1/Psi);
BGUO=YCD/CESGUO;

AGUO=((1-AlphaGUO)*BGUO^Psi*YCD^(-Psi)*(1-delta*KCD/YCD)^(-1))/HCD^(1+Frisch-Psi);

%% Steady State CES

YCES=BGUO*(AlphaGUO*KCD^(Psi)+(1-AlphaGUO)*HCD^(Psi))^(1/Psi);



%% Model

AA=[(Frisch)    (Ltax/(1-Ltax))    -1    0    0;...
    -((Ltax*w*HCD)/G)    -((Ltax*w*HCD+Ctax*(r-delta)*KCD)/G)    -((Ltax*w*HCD)/G)    0    -((Ctax*r*KCD)/G);...
    0    0    0    (-(1/sigma))    1;...
    (1/sigma)    0    1    (-(1/sigma))    0;...
    (-(1-AlphaGUO))*(BGUO*(HCD/YCD))^(Psi)    0    0    1    0];

BB=[0    -1;...
    ((Ctax*(r-delta)*KCD/G))    0;...
    (-(1/sigma))    0;...
    0    0;...
    (AlphaGUO*(BGUO*(KCD/YCD))^(Psi))   0];


XX=(AA)^(-1)*BB;


CC=[-delta    -(CCD/KCD);...
    0    (((r-delta)*(1-Ctax))-pi)];
    

DD=[0    0    0    (YCD/KCD)    0;...
    0    -Ctax*(r-delta)    0    0    r*(1-Ctax)];



matrix=(DD*(AA\BB))+CC;
     
deter=det(matrix); 
tr=trace(matrix);

if deter<0;    %as many eig. outside unit circle as jump varbls
                frontier(counter,counter1)=2;
elseif tr > 0; %too few unstable: indeterminacy
                frontier(counter,counter1)=1;
else  %too many unstable:non-existence
                frontier(counter,counter1)=0;
end;


   
   
     end
end
ncol=ncol+1;
startin=startin+0.1;


figure(1);
hold all
colormap([1 1 1])
subplot(3,3,1);
contourf(LTax,CTax,frontier(:,:)); hold on
 %plot(LTax(pos_th),CTax(pos_tk),'k*', 'LineWidth',1,'markersize',4);
     

title('\sigma=1.8');
             xlabel('\tau^h','FontName','Sakkal Majalla','Fontsize',11);
        ylabel('\tau^k','FontName','Sakkal Majalla','Fontsize',11);
     
for counter=1:1:sise1;
    Ctax=CTax(counter);
    for counter1=1:1:sise2
        Ltax=LTax(counter1);
sigma=1.6;        
if sigma==1
    sigma=1.00001;
end

%% Steady State Cobb Douglas
r=((1-Ctax)*delta+pi)/(1-Ctax); % interest rate
GammaCD=(r*(1/AlphaCD))^(1/(1-AlphaCD));
PiCD=((1-AlphaCD)*GammaCD^(1-AlphaCD)*Ltax)+(AlphaCD*GammaCD^(1-AlphaCD)-delta)*Ctax;
KCD=(((1-AlphaCD)*GammaCD^(-AlphaCD)*(1-Ltax))/(ACD*GammaCD^Frisch*(GammaCD^(1-AlphaCD)-PiCD-delta)))^(1/(1+Frisch)); % S.S. Capital
HCD=GammaCD*KCD;  % S.S. Labour
KCD_HCD=KCD/HCD; % Capital-Labour Ratio
CCD=(GammaCD^(1-AlphaCD)-PiCD-delta)*KCD; % S.S. Consumption
G=PiCD*KCD;  % S.S. Government
Psi=(sigma-1)/sigma;   
w=(1-AlphaCD)*GammaCD^(-AlphaCD);   % S.S. Wages
YCD=KCD^AlphaCD*HCD^(1-AlphaCD);   % S.S Output



        
%% Parameters CES

AlphaGUO=(AlphaCD)/(AlphaCD+(1-AlphaCD)*(KCD_HCD)^Psi);

CESGUO=(AlphaGUO*(KCD)^Psi+(1-AlphaGUO)*(HCD)^Psi)^(1/Psi);
BGUO=YCD/CESGUO;

AGUO=((1-AlphaGUO)*BGUO^Psi*YCD^(-Psi)*(1-delta*KCD/YCD)^(-1))/HCD^(1+Frisch-Psi);

%% Steady State CES

YCES=BGUO*(AlphaGUO*KCD^(Psi)+(1-AlphaGUO)*HCD^(Psi))^(1/Psi);



%% Model

AA=[(Frisch)    (Ltax/(1-Ltax))    -1    0    0;...
    -((Ltax*w*HCD)/G)    -((Ltax*w*HCD+Ctax*(r-delta)*KCD)/G)    -((Ltax*w*HCD)/G)    0    -((Ctax*r*KCD)/G);...
    0    0    0    (-(1/sigma))    1;...
    (1/sigma)    0    1    (-(1/sigma))    0;...
    (-(1-AlphaGUO))*(BGUO*(HCD/YCD))^(Psi)    0    0    1    0];

BB=[0    -1;...
    ((Ctax*(r-delta)*KCD/G))    0;...
    (-(1/sigma))    0;...
    0    0;...
    (AlphaGUO*(BGUO*(KCD/YCD))^(Psi))   0];


XX=(AA)^(-1)*BB;


CC=[-delta    -(CCD/KCD);...
    0    (((r-delta)*(1-Ctax))-pi)];
    

DD=[0    0    0    (YCD/KCD)    0;...
    0    -Ctax*(r-delta)    0    0    r*(1-Ctax)];



matrix=(DD*(AA\BB))+CC;
     
deter=det(matrix); 
tr=trace(matrix);

if deter<0;    %as many eig. outside unit circle as jump varbls
                frontier(counter,counter1)=2;
elseif tr > 0; %too few unstable: indeterminacy
                frontier(counter,counter1)=1;
else  %too many unstable:non-existence
                frontier(counter,counter1)=0;
end;




   
   
     end
end
ncol=ncol+1;
startin=startin+0.1;



figure(1);
hold all
colormap([1 1 1])
subplot(3,3,2);
contourf(LTax,CTax,frontier(:,:)); hold on

     

title('\sigma=1.6');    
        xlabel('\tau^h','FontName','Sakkal Majalla','Fontsize',11);
        ylabel('\tau^k','FontName','Sakkal Majalla','Fontsize',11);

            
for counter=1:1:sise1;
    Ctax=CTax(counter);
    for counter1=1:1:sise2
        Ltax=LTax(counter1);
sigma=1.4;        
if sigma==1
    sigma=1.00001;
end

%% Steady State Cobb Douglas
r=((1-Ctax)*delta+pi)/(1-Ctax); % interest rate
GammaCD=(r*(1/AlphaCD))^(1/(1-AlphaCD));
PiCD=((1-AlphaCD)*GammaCD^(1-AlphaCD)*Ltax)+(AlphaCD*GammaCD^(1-AlphaCD)-delta)*Ctax;
KCD=(((1-AlphaCD)*GammaCD^(-AlphaCD)*(1-Ltax))/(ACD*GammaCD^Frisch*(GammaCD^(1-AlphaCD)-PiCD-delta)))^(1/(1+Frisch)); % S.S. Capital
HCD=GammaCD*KCD;  % S.S. Labour
KCD_HCD=KCD/HCD; % Capital-Labour Ratio
CCD=(GammaCD^(1-AlphaCD)-PiCD-delta)*KCD; % S.S. Consumption
G=PiCD*KCD;  % S.S. Government
Psi=(sigma-1)/sigma;   
w=(1-AlphaCD)*GammaCD^(-AlphaCD);   % S.S. Wages
YCD=KCD^AlphaCD*HCD^(1-AlphaCD);   % S.S Output



        
%% Parameters CES

AlphaGUO=(AlphaCD)/(AlphaCD+(1-AlphaCD)*(KCD_HCD)^Psi);

CESGUO=(AlphaGUO*(KCD)^Psi+(1-AlphaGUO)*(HCD)^Psi)^(1/Psi);
BGUO=YCD/CESGUO;

AGUO=((1-AlphaGUO)*BGUO^Psi*YCD^(-Psi)*(1-delta*KCD/YCD)^(-1))/HCD^(1+Frisch-Psi);

%% Steady State CES

YCES=BGUO*(AlphaGUO*KCD^(Psi)+(1-AlphaGUO)*HCD^(Psi))^(1/Psi);



%% Model

AA=[(Frisch)    (Ltax/(1-Ltax))    -1    0    0;...
    -((Ltax*w*HCD)/G)    -((Ltax*w*HCD+Ctax*(r-delta)*KCD)/G)    -((Ltax*w*HCD)/G)    0    -((Ctax*r*KCD)/G);...
    0    0    0    (-(1/sigma))    1;...
    (1/sigma)    0    1    (-(1/sigma))    0;...
    (-(1-AlphaGUO))*(BGUO*(HCD/YCD))^(Psi)    0    0    1    0];

BB=[0    -1;...
    ((Ctax*(r-delta)*KCD/G))    0;...
    (-(1/sigma))    0;...
    0    0;...
    (AlphaGUO*(BGUO*(KCD/YCD))^(Psi))   0];


XX=(AA)^(-1)*BB;


CC=[-delta    -(CCD/KCD);...
    0    (((r-delta)*(1-Ctax))-pi)];
    

DD=[0    0    0    (YCD/KCD)    0;...
    0    -Ctax*(r-delta)    0    0    r*(1-Ctax)];



matrix=(DD*(AA\BB))+CC;
     
deter=det(matrix); 
tr=trace(matrix);

if deter<0;    %as many eig. outside unit circle as jump varbls
                frontier(counter,counter1)=2;
elseif tr > 0; %too few unstable: indeterminacy
                frontier(counter,counter1)=1;
else  %too many unstable:non-existence
                frontier(counter,counter1)=0;
end;



   
   
     end
end
ncol=ncol+1;
startin=startin+0.1;

figure(1);
hold all
colormap([1 1 1])
subplot(3,3,3);
contourf(LTax,CTax,frontier(:,:)); hold on
 %plot(LTax(pos_th),CTax(pos_tk),'k*', 'LineWidth',1,'markersize',4);
     

title(' \sigma=1.4');
               xlabel('\tau^h','FontName','Sakkal Majalla','Fontsize',11);
        ylabel('\tau^k','FontName','Sakkal Majalla','Fontsize',11);
        
        
for counter=1:1:sise1;
    Ctax=CTax(counter);
    for counter1=1:1:sise2
        Ltax=LTax(counter1);
sigma=1.2;        
if sigma==1
    sigma=1.00001;
end

%% Steady State Cobb Douglas
r=((1-Ctax)*delta+pi)/(1-Ctax); % interest rate
GammaCD=(r*(1/AlphaCD))^(1/(1-AlphaCD));
PiCD=((1-AlphaCD)*GammaCD^(1-AlphaCD)*Ltax)+(AlphaCD*GammaCD^(1-AlphaCD)-delta)*Ctax;
KCD=(((1-AlphaCD)*GammaCD^(-AlphaCD)*(1-Ltax))/(ACD*GammaCD^Frisch*(GammaCD^(1-AlphaCD)-PiCD-delta)))^(1/(1+Frisch)); % S.S. Capital
HCD=GammaCD*KCD;  % S.S. Labour
KCD_HCD=KCD/HCD; % Capital-Labour Ratio
CCD=(GammaCD^(1-AlphaCD)-PiCD-delta)*KCD; % S.S. Consumption
G=PiCD*KCD;  % S.S. Government
Psi=(sigma-1)/sigma;   
w=(1-AlphaCD)*GammaCD^(-AlphaCD);   % S.S. Wages
YCD=KCD^AlphaCD*HCD^(1-AlphaCD);   % S.S Output




        
%% Parameters CES

AlphaGUO=(AlphaCD)/(AlphaCD+(1-AlphaCD)*(KCD_HCD)^Psi);

CESGUO=(AlphaGUO*(KCD)^Psi+(1-AlphaGUO)*(HCD)^Psi)^(1/Psi);
BGUO=YCD/CESGUO;

AGUO=((1-AlphaGUO)*BGUO^Psi*YCD^(-Psi)*(1-delta*KCD/YCD)^(-1))/HCD^(1+Frisch-Psi);

%% Steady State CES

YCES=BGUO*(AlphaGUO*KCD^(Psi)+(1-AlphaGUO)*HCD^(Psi))^(1/Psi);



%% Model

AA=[(Frisch)    (Ltax/(1-Ltax))    -1    0    0;...
    -((Ltax*w*HCD)/G)    -((Ltax*w*HCD+Ctax*(r-delta)*KCD)/G)    -((Ltax*w*HCD)/G)    0    -((Ctax*r*KCD)/G);...
    0    0    0    (-(1/sigma))    1;...
    (1/sigma)    0    1    (-(1/sigma))    0;...
    (-(1-AlphaGUO))*(BGUO*(HCD/YCD))^(Psi)    0    0    1    0];

BB=[0    -1;...
    ((Ctax*(r-delta)*KCD/G))    0;...
    (-(1/sigma))    0;...
    0    0;...
    (AlphaGUO*(BGUO*(KCD/YCD))^(Psi))   0];


XX=(AA)^(-1)*BB;


CC=[-delta    -(CCD/KCD);...
    0    (((r-delta)*(1-Ctax))-pi)];
    

DD=[0    0    0    (YCD/KCD)    0;...
    0    -Ctax*(r-delta)    0    0    r*(1-Ctax)];



matrix=(DD*(AA\BB))+CC;
     
deter=det(matrix); 
tr=trace(matrix);

if deter<0;    %as many eig. outside unit circle as jump varbls
                frontier(counter,counter1)=2;
elseif tr > 0; %too few unstable: indeterminacy
                frontier(counter,counter1)=1;
else  %too many unstable:non-existence
                frontier(counter,counter1)=0;
end;



   
   
   
     end
end
ncol=ncol+1;
startin=startin+0.1;



figure(1);
hold all
colormap([1 1 1])
subplot(3,3,4);
contourf(LTax,CTax,frontier(:,:)); hold on

     

title('\sigma=1.2');
     xlabel('\tau^h','FontName','Sakkal Majalla','Fontsize',11);
        ylabel('\tau^k','FontName','Sakkal Majalla','Fontsize',11);
            
for counter=1:1:sise1;
    Ctax=CTax(counter);
    for counter1=1:1:sise2
        Ltax=LTax(counter1);
sigma=1;        
if sigma==1
    sigma=1.00001;
end

%% Steady State Cobb Douglas
r=((1-Ctax)*delta+pi)/(1-Ctax); % interest rate
GammaCD=(r*(1/AlphaCD))^(1/(1-AlphaCD));
PiCD=((1-AlphaCD)*GammaCD^(1-AlphaCD)*Ltax)+(AlphaCD*GammaCD^(1-AlphaCD)-delta)*Ctax;
KCD=(((1-AlphaCD)*GammaCD^(-AlphaCD)*(1-Ltax))/(ACD*GammaCD^Frisch*(GammaCD^(1-AlphaCD)-PiCD-delta)))^(1/(1+Frisch)); % S.S. Capital
HCD=GammaCD*KCD;  % S.S. Labour
KCD_HCD=KCD/HCD; % Capital-Labour Ratio
CCD=(GammaCD^(1-AlphaCD)-PiCD-delta)*KCD; % S.S. Consumption
G=PiCD*KCD;  % S.S. Government
Psi=(sigma-1)/sigma;   
w=(1-AlphaCD)*GammaCD^(-AlphaCD);   % S.S. Wages
YCD=KCD^AlphaCD*HCD^(1-AlphaCD);   % S.S Output




        
%% Parameters CES

AlphaGUO=(AlphaCD)/(AlphaCD+(1-AlphaCD)*(KCD_HCD)^Psi);

CESGUO=(AlphaGUO*(KCD)^Psi+(1-AlphaGUO)*(HCD)^Psi)^(1/Psi);
BGUO=YCD/CESGUO;

AGUO=((1-AlphaGUO)*BGUO^Psi*YCD^(-Psi)*(1-delta*KCD/YCD)^(-1))/HCD^(1+Frisch-Psi);

%% Steady State CES

YCES=BGUO*(AlphaGUO*KCD^(Psi)+(1-AlphaGUO)*HCD^(Psi))^(1/Psi);



%% Model

AA=[(Frisch)    (Ltax/(1-Ltax))    -1    0    0;...
    -((Ltax*w*HCD)/G)    -((Ltax*w*HCD+Ctax*(r-delta)*KCD)/G)    -((Ltax*w*HCD)/G)    0    -((Ctax*r*KCD)/G);...
    0    0    0    (-(1/sigma))    1;...
    (1/sigma)    0    1    (-(1/sigma))    0;...
    (-(1-AlphaGUO))*(BGUO*(HCD/YCD))^(Psi)    0    0    1    0];

BB=[0    -1;...
    ((Ctax*(r-delta)*KCD/G))    0;...
    (-(1/sigma))    0;...
    0    0;...
    (AlphaGUO*(BGUO*(KCD/YCD))^(Psi))   0];


XX=(AA)^(-1)*BB;


CC=[-delta    -(CCD/KCD);...
    0    (((r-delta)*(1-Ctax))-pi)];
    

DD=[0    0    0    (YCD/KCD)    0;...
    0    -Ctax*(r-delta)    0    0    r*(1-Ctax)];



matrix=(DD*(AA\BB))+CC;
     
deter=det(matrix); 
tr=trace(matrix);

if deter<0;    %as many eig. outside unit circle as jump varbls
                frontier(counter,counter1)=2;
elseif tr > 0; %too few unstable: indeterminacy
                frontier(counter,counter1)=1;
else  %too many unstable:non-existence
                frontier(counter,counter1)=0;
end;




   
   
   
     end
end
ncol=ncol+1;
startin=startin+0.1;


figure(1);
hold all
colormap([1 1 1])
subplot(3,3,5);
contourf(LTax,CTax,frontier(:,:));
title('\sigma=1');
     xlabel('\tau^h','FontName','Sakkal Majalla','Fontsize',11);
        ylabel('\tau^k','FontName','Sakkal Majalla','Fontsize',11);
            
for counter=1:1:sise1;
    Ctax=CTax(counter);
    for counter1=1:1:sise2
        Ltax=LTax(counter1);
sigma=0.8;        
if sigma==1
    sigma=1.00001;
end

%% Steady State Cobb Douglas
r=((1-Ctax)*delta+pi)/(1-Ctax); % interest rate
GammaCD=(r*(1/AlphaCD))^(1/(1-AlphaCD));
PiCD=((1-AlphaCD)*GammaCD^(1-AlphaCD)*Ltax)+(AlphaCD*GammaCD^(1-AlphaCD)-delta)*Ctax;
KCD=(((1-AlphaCD)*GammaCD^(-AlphaCD)*(1-Ltax))/(ACD*GammaCD^Frisch*(GammaCD^(1-AlphaCD)-PiCD-delta)))^(1/(1+Frisch)); % S.S. Capital
HCD=GammaCD*KCD;  % S.S. Labour
KCD_HCD=KCD/HCD; % Capital-Labour Ratio
CCD=(GammaCD^(1-AlphaCD)-PiCD-delta)*KCD; % S.S. Consumption
G=PiCD*KCD;  % S.S. Government
Psi=(sigma-1)/sigma;   
w=(1-AlphaCD)*GammaCD^(-AlphaCD);   % S.S. Wages
YCD=KCD^AlphaCD*HCD^(1-AlphaCD);   % S.S Output



        
%% Parameters CES

AlphaGUO=(AlphaCD)/(AlphaCD+(1-AlphaCD)*(KCD_HCD)^Psi);

CESGUO=(AlphaGUO*(KCD)^Psi+(1-AlphaGUO)*(HCD)^Psi)^(1/Psi);
BGUO=YCD/CESGUO;

AGUO=((1-AlphaGUO)*BGUO^Psi*YCD^(-Psi)*(1-delta*KCD/YCD)^(-1))/HCD^(1+Frisch-Psi);

%% Steady State CES

YCES=BGUO*(AlphaGUO*KCD^(Psi)+(1-AlphaGUO)*HCD^(Psi))^(1/Psi);



%% Model

AA=[(Frisch)    (Ltax/(1-Ltax))    -1    0    0;...
    -((Ltax*w*HCD)/G)    -((Ltax*w*HCD+Ctax*(r-delta)*KCD)/G)    -((Ltax*w*HCD)/G)    0    -((Ctax*r*KCD)/G);...
    0    0    0    (-(1/sigma))    1;...
    (1/sigma)    0    1    (-(1/sigma))    0;...
    (-(1-AlphaGUO))*(BGUO*(HCD/YCD))^(Psi)    0    0    1    0];

BB=[0    -1;...
    ((Ctax*(r-delta)*KCD/G))    0;...
    (-(1/sigma))    0;...
    0    0;...
    (AlphaGUO*(BGUO*(KCD/YCD))^(Psi))   0];


XX=(AA)^(-1)*BB;


CC=[-delta    -(CCD/KCD);...
    0    (((r-delta)*(1-Ctax))-pi)];
    

DD=[0    0    0    (YCD/KCD)    0;...
    0    -Ctax*(r-delta)    0    0    r*(1-Ctax)];



matrix=(DD*(AA\BB))+CC;
     
deter=det(matrix); 
tr=trace(matrix);

if deter<0;    %as many eig. outside unit circle as jump varbls
                frontier(counter,counter1)=2;
elseif tr > 0; %too few unstable: indeterminacy
                frontier(counter,counter1)=1;
else  %too many unstable:non-existence
                frontier(counter,counter1)=0;
end;




   
   
   
     end
end
ncol=ncol+1;
startin=startin+0.1;


figure(1);
hold all
colormap([1 1 1])
subplot(3,3,6);
contourf(LTax,CTax,frontier(:,:)); hold on
title('\sigma=0.8');
     xlabel('\tau^h','FontName','Sakkal Majalla','Fontsize',11);
        ylabel('\tau^k','FontName','Sakkal Majalla','Fontsize',11);
            
for counter=1:1:sise1;
    Ctax=CTax(counter);
    for counter1=1:1:sise2
        Ltax=LTax(counter1);
sigma=0.6;        
if sigma==1
    sigma=1.00001;
end

%% Steady State Cobb Douglas
r=((1-Ctax)*delta+pi)/(1-Ctax); % interest rate
GammaCD=(r*(1/AlphaCD))^(1/(1-AlphaCD));
PiCD=((1-AlphaCD)*GammaCD^(1-AlphaCD)*Ltax)+(AlphaCD*GammaCD^(1-AlphaCD)-delta)*Ctax;
KCD=(((1-AlphaCD)*GammaCD^(-AlphaCD)*(1-Ltax))/(ACD*GammaCD^Frisch*(GammaCD^(1-AlphaCD)-PiCD-delta)))^(1/(1+Frisch)); % S.S. Capital
HCD=GammaCD*KCD;  % S.S. Labour
KCD_HCD=KCD/HCD; % Capital-Labour Ratio
CCD=(GammaCD^(1-AlphaCD)-PiCD-delta)*KCD; % S.S. Consumption
G=PiCD*KCD;  % S.S. Government
Psi=(sigma-1)/sigma;   
w=(1-AlphaCD)*GammaCD^(-AlphaCD);   % S.S. Wages
YCD=KCD^AlphaCD*HCD^(1-AlphaCD);   % S.S Output




        
%% Parameters CES

AlphaGUO=(AlphaCD)/(AlphaCD+(1-AlphaCD)*(KCD_HCD)^Psi);

CESGUO=(AlphaGUO*(KCD)^Psi+(1-AlphaGUO)*(HCD)^Psi)^(1/Psi);
BGUO=YCD/CESGUO;

AGUO=((1-AlphaGUO)*BGUO^Psi*YCD^(-Psi)*(1-delta*KCD/YCD)^(-1))/HCD^(1+Frisch-Psi);

%% Steady State CES

YCES=BGUO*(AlphaGUO*KCD^(Psi)+(1-AlphaGUO)*HCD^(Psi))^(1/Psi);



%% Model

AA=[(Frisch)    (Ltax/(1-Ltax))    -1    0    0;...
    -((Ltax*w*HCD)/G)    -((Ltax*w*HCD+Ctax*(r-delta)*KCD)/G)    -((Ltax*w*HCD)/G)    0    -((Ctax*r*KCD)/G);...
    0    0    0    (-(1/sigma))    1;...
    (1/sigma)    0    1    (-(1/sigma))    0;...
    (-(1-AlphaGUO))*(BGUO*(HCD/YCD))^(Psi)    0    0    1    0];

BB=[0    -1;...
    ((Ctax*(r-delta)*KCD/G))    0;...
    (-(1/sigma))    0;...
    0    0;...
    (AlphaGUO*(BGUO*(KCD/YCD))^(Psi))   0];


XX=(AA)^(-1)*BB;


CC=[-delta    -(CCD/KCD);...
    0    (((r-delta)*(1-Ctax))-pi)];
    

DD=[0    0    0    (YCD/KCD)    0;...
    0    -Ctax*(r-delta)    0    0    r*(1-Ctax)];



matrix=(DD*(AA\BB))+CC;
     
deter=det(matrix); 
tr=trace(matrix);

if deter<0;    %as many eig. outside unit circle as jump varbls
                frontier(counter,counter1)=2;
elseif tr > 0; %too few unstable: indeterminacy
                frontier(counter,counter1)=1;
else  %too many unstable:non-existence
                frontier(counter,counter1)=0;
end;



   
   
   
     end
end
ncol=ncol+1;
startin=startin+0.1;

figure(1);
hold all
colormap([1 1 1])
subplot(3,3,7);
contourf(LTax,CTax,frontier(:,:)); hold on
title('\sigma=0.6');
     xlabel('\tau^h','FontName','Sakkal Majalla','Fontsize',11);
        ylabel('\tau^k','FontName','Sakkal Majalla','Fontsize',11);
            
for counter=1:1:sise1;
    Ctax=CTax(counter);
    for counter1=1:1:sise2
        Ltax=LTax(counter1);
sigma=0.4;        
if sigma==1
    sigma=1.00001;
end

%% Steady State Cobb Douglas
r=((1-Ctax)*delta+pi)/(1-Ctax); % interest rate
GammaCD=(r*(1/AlphaCD))^(1/(1-AlphaCD));
PiCD=((1-AlphaCD)*GammaCD^(1-AlphaCD)*Ltax)+(AlphaCD*GammaCD^(1-AlphaCD)-delta)*Ctax;
KCD=(((1-AlphaCD)*GammaCD^(-AlphaCD)*(1-Ltax))/(ACD*GammaCD^Frisch*(GammaCD^(1-AlphaCD)-PiCD-delta)))^(1/(1+Frisch)); % S.S. Capital
HCD=GammaCD*KCD;  % S.S. Labour
KCD_HCD=KCD/HCD; % Capital-Labour Ratio
CCD=(GammaCD^(1-AlphaCD)-PiCD-delta)*KCD; % S.S. Consumption
G=PiCD*KCD;  % S.S. Government
Psi=(sigma-1)/sigma;   
w=(1-AlphaCD)*GammaCD^(-AlphaCD);   % S.S. Wages
YCD=KCD^AlphaCD*HCD^(1-AlphaCD);   % S.S Output




        
%% Parameters CES

AlphaGUO=(AlphaCD)/(AlphaCD+(1-AlphaCD)*(KCD_HCD)^Psi);

CESGUO=(AlphaGUO*(KCD)^Psi+(1-AlphaGUO)*(HCD)^Psi)^(1/Psi);
BGUO=YCD/CESGUO;

AGUO=((1-AlphaGUO)*BGUO^Psi*YCD^(-Psi)*(1-delta*KCD/YCD)^(-1))/HCD^(1+Frisch-Psi);

%% Steady State CES

YCES=BGUO*(AlphaGUO*KCD^(Psi)+(1-AlphaGUO)*HCD^(Psi))^(1/Psi);



%% Model

AA=[(Frisch)    (Ltax/(1-Ltax))    -1    0    0;...
    -((Ltax*w*HCD)/G)    -((Ltax*w*HCD+Ctax*(r-delta)*KCD)/G)    -((Ltax*w*HCD)/G)    0    -((Ctax*r*KCD)/G);...
    0    0    0    (-(1/sigma))    1;...
    (1/sigma)    0    1    (-(1/sigma))    0;...
    (-(1-AlphaGUO))*(BGUO*(HCD/YCD))^(Psi)    0    0    1    0];

BB=[0    -1;...
    ((Ctax*(r-delta)*KCD/G))    0;...
    (-(1/sigma))    0;...
    0    0;...
    (AlphaGUO*(BGUO*(KCD/YCD))^(Psi))   0];


XX=(AA)^(-1)*BB;


CC=[-delta    -(CCD/KCD);...
    0    (((r-delta)*(1-Ctax))-pi)];
    

DD=[0    0    0    (YCD/KCD)    0;...
    0    -Ctax*(r-delta)    0    0    r*(1-Ctax)];



matrix=(DD*(AA\BB))+CC;
     
deter=det(matrix); 
tr=trace(matrix);

if deter<0;    %as many eig. outside unit circle as jump varbls
                frontier(counter,counter1)=2;
elseif tr > 0; %too few unstable: indeterminacy
                frontier(counter,counter1)=1;
else  %too many unstable:non-existence
                frontier(counter,counter1)=0;
end;

% (These effects are consistent with a positive slope in the LDS, i.e. a decreases in aggregate employment are accompanied by increases in the tax rate.)


   
   
   
     end
end
ncol=ncol+1;
startin=startin+0.1;


figure(1);
hold all
colormap([1 1 1])
subplot(3,3,8);
contourf(LTax,CTax,frontier(:,:)); hold on
 title('\sigma=0.4');
     xlabel('\tau^h','FontName','Sakkal Majalla','Fontsize',11);
        ylabel('\tau^k','FontName','Sakkal Majalla','Fontsize',11);

            
for counter=1:1:sise1;
    Ctax=CTax(counter);
    for counter1=1:1:sise2
        Ltax=LTax(counter1);
sigma=.2;        
if sigma==1
    sigma=1.00001;
end

%% Steady State Cobb Douglas
r=((1-Ctax)*delta+pi)/(1-Ctax); % interest rate
GammaCD=(r*(1/AlphaCD))^(1/(1-AlphaCD));
PiCD=((1-AlphaCD)*GammaCD^(1-AlphaCD)*Ltax)+(AlphaCD*GammaCD^(1-AlphaCD)-delta)*Ctax;
KCD=(((1-AlphaCD)*GammaCD^(-AlphaCD)*(1-Ltax))/(ACD*GammaCD^Frisch*(GammaCD^(1-AlphaCD)-PiCD-delta)))^(1/(1+Frisch)); % S.S. Capital
HCD=GammaCD*KCD;  % S.S. Labour
KCD_HCD=KCD/HCD; % Capital-Labour Ratio
CCD=(GammaCD^(1-AlphaCD)-PiCD-delta)*KCD; % S.S. Consumption
G=PiCD*KCD;  % S.S. Government
Psi=(sigma-1)/sigma;   
w=(1-AlphaCD)*GammaCD^(-AlphaCD);   % S.S. Wages
YCD=KCD^AlphaCD*HCD^(1-AlphaCD);   % S.S Output




        
%% Parameters CES

AlphaGUO=(AlphaCD)/(AlphaCD+(1-AlphaCD)*(KCD_HCD)^Psi);

CESGUO=(AlphaGUO*(KCD)^Psi+(1-AlphaGUO)*(HCD)^Psi)^(1/Psi);
BGUO=YCD/CESGUO;

AGUO=((1-AlphaGUO)*BGUO^Psi*YCD^(-Psi)*(1-delta*KCD/YCD)^(-1))/HCD^(1+Frisch-Psi);

%% Steady State CES

YCES=BGUO*(AlphaGUO*KCD^(Psi)+(1-AlphaGUO)*HCD^(Psi))^(1/Psi);



%% Model

AA=[(Frisch)    (Ltax/(1-Ltax))    -1    0    0;...
    -((Ltax*w*HCD)/G)    -((Ltax*w*HCD+Ctax*(r-delta)*KCD)/G)    -((Ltax*w*HCD)/G)    0    -((Ctax*r*KCD)/G);...
    0    0    0    (-(1/sigma))    1;...
    (1/sigma)    0    1    (-(1/sigma))    0;...
    (-(1-AlphaGUO))*(BGUO*(HCD/YCD))^(Psi)    0    0    1    0];

BB=[0    -1;...
    ((Ctax*(r-delta)*KCD/G))    0;...
    (-(1/sigma))    0;...
    0    0;...
    (AlphaGUO*(BGUO*(KCD/YCD))^(Psi))   0];


XX=(AA)^(-1)*BB;


CC=[-delta    -(CCD/KCD);...
    0    (((r-delta)*(1-Ctax))-pi)];
    

DD=[0    0    0    (YCD/KCD)    0;...
    0    -Ctax*(r-delta)    0    0    r*(1-Ctax)];



matrix=(DD*(AA\BB))+CC;
     
deter=det(matrix); 
tr=trace(matrix);

if deter<0;    %as many eig. outside unit circle as jump varbls
                frontier(counter,counter1)=2;
elseif tr > 0; %too few unstable: indeterminacy
                frontier(counter,counter1)=1;
else  %too many unstable:non-existence
                frontier(counter,counter1)=0;
end;


   
   
   
     end
end
ncol=ncol+1;
startin=startin+0.1;


figure(1);
hold all
colormap([1 1 1])
subplot(3,3,9);
contourf(LTax,CTax,frontier(:,:));
 title('\sigma=0.2');
       xlabel('\tau^h','FontName','Sakkal Majalla','Fontsize',11);
        ylabel('\tau^k','FontName','Sakkal Majalla','Fontsize',11);          
