% Aggregate Stability and Balanced-Budget Rules
% Matteo F. Ghilardi and Raffaele Rossi
%
% This code reproduces the results of table 3 in the paper
% The results are stored in the variables valueUS, valueEU, value UK

clc
clear all

%% Parameters

betta=0.96;
delta=0.1;
theta=0.3;
vp=0;
ACD=1;
AlphaCD=0.3;
Frisch=0;
pi=0.04;

taxes = xlsread('taxes.xls');

Sigma=(0.2:0.01:1.8);

aaaa=size(Sigma);
sise1=aaaa(2);
bbbb=size(taxes);
sise2=bbbb(1);
sise3=bbbb(2);


treshold=zeros(sise2,16);

contatore=1;
%% Loops
for i2=2:2:sise3

    for i=1:1:sise2
    

    for counter=1:1:sise1;
    sigma=Sigma(counter);

        
     if sigma==1
         sigma=1.001;
     end
    
     i2bis=i2+1;
  
   Ctax=taxes(i,i2);
   Ltax=taxes(i,i2bis);

%% Steady State Cobb Douglas
r=((1-Ctax)*delta+pi)/(1-Ctax); % interest rate
GammaCD=(r*(1/AlphaCD))^(1/(1-AlphaCD));
PiCD=((1-AlphaCD)*GammaCD^(1-AlphaCD)*Ltax)+(AlphaCD*GammaCD^(1-AlphaCD)-delta)*Ctax;
KCD=(((1-AlphaCD)*GammaCD^(-AlphaCD)*(1-Ltax))/(ACD*GammaCD^Frisch*(GammaCD^(1-AlphaCD)-PiCD-delta)))^(1/(1+Frisch)); % S.S. Capital
HCD=GammaCD*KCD;  % S.S. Labour
KCD_HCD=KCD/HCD; % Capital-Labour Ratio
CCD=(GammaCD^(1-AlphaCD)-PiCD-delta)*KCD; % S.S. Consumption
G=PiCD*KCD;  % S.S. Government
Psi=(sigma-1)/sigma;   
w=(1-AlphaCD)*GammaCD^(-AlphaCD);   % S.S. Wages
YCD=KCD^AlphaCD*HCD^(1-AlphaCD);   % S.S Output




        
%% Parameters CES

AlphaGUO=(AlphaCD)/(AlphaCD+(1-AlphaCD)*(KCD_HCD)^Psi);
CESGUO=(AlphaGUO*(KCD)^Psi+(1-AlphaGUO)*(HCD)^Psi)^(1/Psi);
BGUO=YCD/CESGUO;
AGUO=((1-AlphaGUO)*BGUO^Psi*YCD^(-Psi)*(1-delta*KCD/YCD)^(-1))/HCD^(1+Frisch-Psi);

%% Steady State CES

YCES=BGUO*(AlphaGUO*KCD^(Psi)+(1-AlphaGUO)*HCD^(Psi))^(1/Psi);



%% Model

AA=[(Frisch)    (Ltax/(1-Ltax))    -1    0    0;...
    -((Ltax*w*HCD)/G)    -((Ltax*w*HCD+Ctax*(r-delta)*KCD)/G)    -((Ltax*w*HCD)/G)    0    -((Ctax*r*KCD)/G);...
    0    0    0    (-(1/sigma))    1;...
    (1/sigma)    0    1    (-(1/sigma))    0;...
    (-(1-AlphaGUO))*(BGUO*(HCD/YCD))^(Psi)    0    0    1    0];

BB=[0    -1;...
    ((Ctax*(r-delta)*KCD/G))    0;...
    (-(1/sigma))    0;...
    0    0;...
    (AlphaGUO*(BGUO*(KCD/YCD))^(Psi))   0];


XX=(AA)^(-1)*BB;


CC=[-delta    -(CCD/KCD);...
    0    (((r-delta)*(1-Ctax))-pi)];
    

DD=[0    0    0    (YCD/KCD)    0;...
    0    -Ctax*(r-delta)    0    0    r*(1-Ctax)];



matrix=(DD*(inv(AA)*BB))+CC;
     
deter=det(matrix); 
tr=trace(matrix);
     
     
     

if deter<0 ; 
    threshold(i,contatore)=sigma;        
end
 


     end
    end
contatore=contatore+1;
end


%% Plot Determinancy Areas

Year=taxes(:,1); 

valueUS=threshold(:,1);
figure (1)
hold all
subplot(2,3,4), bar(Year, valueUS)
    xlabel('Years');
    ylabel('Sigma');
    title('United States');
    axis([1992 2010 0 1.4]);

    
    
valueEU=threshold(:,2);
figure (1)
hold all
subplot(2,3,5), bar(Year, valueEU)
    xlabel('Years');
    ylabel('Sigma');
    title('Europe');
axis([1992 2010 0 1.4]);

    
    
valueUK=threshold(:,3);
figure (1)
hold all
subplot(2,3,6), bar(Year, valueUK)
    xlabel('Years');
    ylabel('Sigma');
    title('United Kingdom');
 axis([1992 2010 0 1.4]);    

    
%% Plot Taxes
taxes = xlsread('taxes.xls');

bbbb=size(taxes);
sise2=bbbb(1);

for i=1:1:sise2
Year=taxes(i,1); 
Ctax=taxes(i,2);
Ltax=taxes(i,3);

figure (1)
hold all
subplot(2,3,1), 
plot (Year, Ctax, '--.k','markersize' ,5);
plot (Year, Ltax, '*r','markersize' ,5);
    xlabel('Years');
    ylabel('Tax Level');
    title('United States')
    axis([1992 2010 0 0.8]);
end

for i=1:1:sise2
Year=taxes(i,1); 
Ctax=taxes(i,4);
Ltax=taxes(i,5);

figure (1)
hold all
subplot(2,3,2),
plot (Year, Ctax, '--.k','markersize' ,5);
plot (Year, Ltax, '*r','markersize' ,5);
    xlabel('Years');
    ylabel('Tax Level');
    title('European Union')
    axis([1992 2010 0 0.8]);
end

for i=1:1:sise2
Year=taxes(i,1); 
Ctax=taxes(i,6);
Ltax=taxes(i,7);

figure (1)
hold all
subplot(2,3,3),
plot (Year, Ctax, '--.k','markersize' ,5);
plot (Year, Ltax, '*r','markersize' ,5);
    xlabel('Years');
    ylabel('Tax Level');
    title('United Kingdom')
    axis([1992 2010 0 0.8]);
end
